# -*- coding: utf-8 -*-
import scrapy, re
from surDeCampeche.items import NoticiasItem

"""
MEDIO:
El Sur de Campeche, Campeche
USO:
scrapy crawl noticias --nolog -s filename=2018-08-10.json -a year=2018 -a month=8 -a day=10
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        year  = getattr(self, "year", None)
        month = getattr(self, "month", None)
        day   = getattr(self, "day", None)

        self.baseURL = "http://www.elsur.mx/" + year + "/" + month + "/" + day

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)
        
        pagination = response.xpath('//a[@class="page-numbers"]/@href').extract()
        if pagination is not None and len(pagination) > 0:
            pages = pagination[-1].rstrip("/")
            pages = int(pages[pages.rfind("/") + 1:])

            for page in range(1, pages):
                yield scrapy.Request(url=self.baseURL+"/page/"+str(page + 1), callback=self.parse_page)


    def parse_page(self, response):
        for link in response.css('div.news_box_inner_content').css('div.news_box_item_content').xpath('./h3/a/@href').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        # La fecha obtenida ya incluye formato y zona horaria
        item['date']  = response.xpath('//meta[@property="article:published_time"]/@content').extract_first()
        item['title'] = remove_tags(response.xpath('//div[@class="post_title_wrapper"]/h1').extract_first())
        
        try:
            topic = remove_tags(response.css('span.blog_meta_category').css('a').extract_first())
        except:
            topic = None
        
        item['topic'] = topic

        for p in response.css('div.entry-content').css('p').extract():
            text += remove_tags(p) + "\n"
        
        item['text'] = text

        item['url'] = response.url

        yield item
